pub trait Executor: Send + Sync {
// Required methods
fn exec<'life0, 'life1, 'async_trait>(
&'life0 self,
cmd: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<ExecOutput>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn exec_streaming<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
cmd: &'life1 str,
prefix: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<ExecOutput>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
fn wait_for_service<'life0, 'life1, 'async_trait>(
&'life0 self,
unit: &'life1 str,
timeout: Duration,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn fetch_dir<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
remote_path: &'life1 str,
local_path: &'life2 Path,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
}Expand description
Abstraction over where commands run — VM (SSH) or local host.
Required Methods
Sourcefn exec<'life0, 'life1, 'async_trait>(
&'life0 self,
cmd: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<ExecOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn exec<'life0, 'life1, 'async_trait>(
&'life0 self,
cmd: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<ExecOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Run a command and return its output. Fails if exit code != 0.
Sourcefn exec_streaming<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
cmd: &'life1 str,
prefix: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<ExecOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn exec_streaming<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
cmd: &'life1 str,
prefix: &'life2 str,
) -> Pin<Box<dyn Future<Output = Result<ExecOutput>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Run a command, streaming stdout/stderr to the terminal.
Sourcefn wait_for_service<'life0, 'life1, 'async_trait>(
&'life0 self,
unit: &'life1 str,
timeout: Duration,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn wait_for_service<'life0, 'life1, 'async_trait>(
&'life0 self,
unit: &'life1 str,
timeout: Duration,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Wait for a systemd user service to become active.
Sourcefn fetch_dir<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
remote_path: &'life1 str,
local_path: &'life2 Path,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn fetch_dir<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
remote_path: &'life1 str,
local_path: &'life2 Path,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Copy a directory from the execution environment to the host. No-op for local execution (files are already on the host).
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".